==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ListPanelItemModelDescriptionMetadata } from "./ListPanelItemModelDescriptionMetadata";
import { ListPanelTemplateItemUpdatingEventArgsDescription } from "./ListPanelTemplateItemUpdatingEventArgsDescription";
/**
 * @hidden
 */
export let ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a == null) {
                ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.c(ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a);
            }
            if (a.k(ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a);
            ListPanelItemModelDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Model", "ExportedType:ListPanelItemModel");
            a.item("ContentRef", "(w:Content,wf:Content)DataRef");
        }
        static d(a) {
            ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.b(a);
            a.ac("ListPanelTemplateItemUpdatingEventArgs", () => new ListPanelTemplateItemUpdatingEventArgsDescription());
            a.ab("ListPanelTemplateItemUpdatingEventArgs", ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a);
        }
    }
    ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata, 'ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata');
    ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a = null;
    return ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ListPanelItemModelDescriptionMetadata } from "./ListPanelItemModelDescriptionMetadata";
import { ListPanelTemplateItemUpdatingEventArgsDescription } from "./ListPanelTemplateItemUpdatingEventArgsDescription";
/**
 * @hidden
 */
export let ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a == null) {
                ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.c(ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a);
            }
            if (a.k(ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a);
            ListPanelItemModelDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Model", "ExportedType:ListPanelItemModel");
            a.item("ContentRef", "(w:Content,wf:Content)DataRef");
            a.item("AvailableWidth", "Number:double");
        }
        static d(a) {
            ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.b(a);
            a.ae("ListPanelTemplateItemUpdatingEventArgs", () => new ListPanelTemplateItemUpdatingEventArgsDescription());
            a.ad("ListPanelTemplateItemUpdatingEventArgs", ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a);
        }
    }
    ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata, 'ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata');
    ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a = null;
    return ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata;
})();
